@@ -30,6 +30,9 @@ class Journal(metaclass=PoolMeta):
     clearing_journal = fields.Many2One('account.journal', 'Clearing Journal',
         states={
             'required': Bool(Eval('clearing_account')),
+            },
+        context={
+            'company': Eval('company', None),
             })
     clearing_posting_delay = fields.TimeDelta(
         "Clearing Posting Delay",
@@ -226,10 +229,17 @@ class Payment(metaclass=PoolMeta):
 
     @property
     def clearing_account(self):
-        if self.line:
-            return self.line.account
-        elif self.account:
-            return self.account
+        transaction = Transaction()
+        context = transaction.context
+        with transaction.set_context(date=context.get('clearing_date')):
+            if self.line:
+                return self.line.account.current()
+            elif self.account:
+                return self.account.current()
+            elif self.kind == 'payable':
+                return self.party.account_payable_used
+            elif self.kind == 'receivable':
+                return self.party.account_receivable_used
 
     @property
     def clearing_party(self):
@@ -260,8 +270,6 @@ class Payment(metaclass=PoolMeta):
         Period = pool.get('account.period')
         Date = pool.get('ir.date')
 
-        if not self.clearing_account:
-            return
         if (not self.journal.clearing_account
                 or not self.journal.clearing_journal):
             return
@@ -303,7 +311,7 @@ class Payment(metaclass=PoolMeta):
             counterpart.debit, counterpart.credit = 0, local_amount
         else:
             counterpart.debit, counterpart.credit = local_amount, 0
-        counterpart.account = self.journal.clearing_account
+        counterpart.account = self.journal.clearing_account.current(date)
         if not local_currency:
             counterpart.amount_second_currency = self.amount.copy_sign(
                 counterpart.debit - counterpart.credit)
